==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeRevisionsTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeRevisionsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public NodeRevisionsTable nodeRevisionsTable;
	public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableLabelHeading nodeRevisionsTableLabelHeading;
	public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableLabelHeading. _32_44_11182118849 _32_44_11182118849;
	public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableOperationsHeading nodeRevisionsTableOperationsHeading;
	public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading. _35_49_170396901 _35_49_170396901;
	public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading._35_49_170396901. _35_89_11274849166 _35_89_11274849166;

    public AbstractNodeRevisionsTemplate(B box) {
        super(box);
        id("nodeRevisionsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (nodeRevisionsTable == null) nodeRevisionsTable = register(new NodeRevisionsTable(box()).<NodeRevisionsTable>id("a249683110").owner(AbstractNodeRevisionsTemplate.this));
		if (nodeRevisionsTable != null) nodeRevisionsTableLabelHeading = nodeRevisionsTable.nodeRevisionsTableLabelHeading;
		if (nodeRevisionsTableLabelHeading != null) _32_44_11182118849 = nodeRevisionsTable.nodeRevisionsTableLabelHeading._32_44_11182118849;
		if (nodeRevisionsTable != null) nodeRevisionsTableOperationsHeading = nodeRevisionsTable.nodeRevisionsTableOperationsHeading;
		if (nodeRevisionsTableOperationsHeading != null) _35_49_170396901 = nodeRevisionsTable.nodeRevisionsTableOperationsHeading._35_49_170396901;
		if (_35_49_170396901 != null) _35_89_11274849166 = nodeRevisionsTable.nodeRevisionsTableOperationsHeading._35_49_170396901._35_89_11274849166;
	}

	public class NodeRevisionsTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Revision> implements io.intino.alexandria.ui.displays.components.collection.Selectable {
		public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableLabelHeading nodeRevisionsTableLabelHeading;
		public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableOperationsHeading nodeRevisionsTableOperationsHeading;

		public NodeRevisionsTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (nodeRevisionsTableLabelHeading == null) nodeRevisionsTableLabelHeading = register(new NodeRevisionsTableLabelHeading(box()).<NodeRevisionsTableLabelHeading>id("a_1759233023").owner(AbstractNodeRevisionsTemplate.this));
			if (nodeRevisionsTableOperationsHeading == null) nodeRevisionsTableOperationsHeading = register(new NodeRevisionsTableOperationsHeading(box()).<NodeRevisionsTableOperationsHeading>id("a1914553990").owner(AbstractNodeRevisionsTemplate.this));
		}
		public void onSelect(io.intino.alexandria.ui.displays.events.SelectionListener listener) {
			super.addSelectionListener(listener);
		}

		public NodeRevisionsTableRow create(org.monet.space.kernel.model.Revision item) {
			NodeRevisionsTableRow row = new NodeRevisionsTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class NodeRevisionsTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableLabelHeading. _32_44_11182118849 _32_44_11182118849;

			public NodeRevisionsTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_32_44_11182118849 == null) _32_44_11182118849 = register(new _32_44_11182118849(box()).<_32_44_11182118849>id("a_142429872").owner(AbstractNodeRevisionsTemplate.this));
			}

			public class _32_44_11182118849 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _32_44_11182118849(B box) {
					super(box);
					_value("Título");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class NodeRevisionsTableOperationsHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading. _35_49_170396901 _35_49_170396901;

			public NodeRevisionsTableOperationsHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_35_49_170396901 == null) _35_49_170396901 = register(new _35_49_170396901(box()).<_35_49_170396901>id("a1264159377").owner(AbstractNodeRevisionsTemplate.this));
			}

			public class _35_49_170396901 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading._35_49_170396901. _35_89_11274849166 _35_89_11274849166;

				public _35_49_170396901(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_35_89_11274849166 == null) _35_89_11274849166 = register(new _35_89_11274849166(box()).<_35_89_11274849166>id("a1627389971").owner(AbstractNodeRevisionsTemplate.this));
				}

				public class _35_89_11274849166 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _35_89_11274849166(B box) {
						super(box);
						_value("Operaciones");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeRevisionsTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeRevisionsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public NodeRevisionsTable nodeRevisionsTable;
	public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableLabelHeading nodeRevisionsTableLabelHeading;
	public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableLabelHeading. _32_44_11182118849 _32_44_11182118849;
	public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableOperationsHeading nodeRevisionsTableOperationsHeading;
	public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading. _35_49_170396901 _35_49_170396901;
	public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading._35_49_170396901. _35_89_11274849166 _35_89_11274849166;

    public AbstractNodeRevisionsTemplate(B box) {
        super(box);
        id("nodeRevisionsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (nodeRevisionsTable == null) nodeRevisionsTable = register(new NodeRevisionsTable(box()).<NodeRevisionsTable>id("a249683110").owner(AbstractNodeRevisionsTemplate.this));
		if (nodeRevisionsTable != null) nodeRevisionsTableLabelHeading = nodeRevisionsTable.nodeRevisionsTableLabelHeading;
		if (nodeRevisionsTableLabelHeading != null) _32_44_11182118849 = nodeRevisionsTable.nodeRevisionsTableLabelHeading._32_44_11182118849;
		if (nodeRevisionsTable != null) nodeRevisionsTableOperationsHeading = nodeRevisionsTable.nodeRevisionsTableOperationsHeading;
		if (nodeRevisionsTableOperationsHeading != null) _35_49_170396901 = nodeRevisionsTable.nodeRevisionsTableOperationsHeading._35_49_170396901;
		if (_35_49_170396901 != null) _35_89_11274849166 = nodeRevisionsTable.nodeRevisionsTableOperationsHeading._35_49_170396901._35_89_11274849166;
	}

    @Override
    public void remove() {
        super.remove();
	    if (nodeRevisionsTable != null) nodeRevisionsTable.unregister();
	}

	public class NodeRevisionsTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Revision> implements io.intino.alexandria.ui.displays.components.collection.Selectable {
		public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableLabelHeading nodeRevisionsTableLabelHeading;
		public NodeRevisionsTemplate.NodeRevisionsTable. NodeRevisionsTableOperationsHeading nodeRevisionsTableOperationsHeading;

		public NodeRevisionsTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (nodeRevisionsTableLabelHeading == null) nodeRevisionsTableLabelHeading = register(new NodeRevisionsTableLabelHeading(box()).<NodeRevisionsTableLabelHeading>id("a_1759233023").owner(AbstractNodeRevisionsTemplate.this));
			if (nodeRevisionsTableOperationsHeading == null) nodeRevisionsTableOperationsHeading = register(new NodeRevisionsTableOperationsHeading(box()).<NodeRevisionsTableOperationsHeading>id("a1914553990").owner(AbstractNodeRevisionsTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (nodeRevisionsTableLabelHeading != null) nodeRevisionsTableLabelHeading.unregister();
			if (nodeRevisionsTableOperationsHeading != null) nodeRevisionsTableOperationsHeading.unregister();
		}
		public void onSelect(io.intino.alexandria.ui.displays.events.SelectionListener listener) {
			super.addSelectionListener(listener);
		}

		public NodeRevisionsTableRow create(org.monet.space.kernel.model.Revision item) {
			NodeRevisionsTableRow row = new NodeRevisionsTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class NodeRevisionsTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableLabelHeading. _32_44_11182118849 _32_44_11182118849;

			public NodeRevisionsTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_32_44_11182118849 == null) _32_44_11182118849 = register(new _32_44_11182118849(box()).<_32_44_11182118849>id("a_142429872").owner(AbstractNodeRevisionsTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_32_44_11182118849 != null) _32_44_11182118849.unregister();
			}

			public class _32_44_11182118849 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _32_44_11182118849(B box) {
					super(box);
					_value("Título");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class NodeRevisionsTableOperationsHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading. _35_49_170396901 _35_49_170396901;

			public NodeRevisionsTableOperationsHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_35_49_170396901 == null) _35_49_170396901 = register(new _35_49_170396901(box()).<_35_49_170396901>id("a1264159377").owner(AbstractNodeRevisionsTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_35_49_170396901 != null) _35_49_170396901.unregister();
			}

			public class _35_49_170396901 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public NodeRevisionsTemplate.NodeRevisionsTable.NodeRevisionsTableOperationsHeading._35_49_170396901. _35_89_11274849166 _35_89_11274849166;

				public _35_49_170396901(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_35_89_11274849166 == null) _35_89_11274849166 = register(new _35_89_11274849166(box()).<_35_89_11274849166>id("a1627389971").owner(AbstractNodeRevisionsTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_35_89_11274849166 != null) _35_89_11274849166.unregister();
				}

				public class _35_89_11274849166 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public _35_89_11274849166(B box) {
						super(box);
						_value("Operaciones");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}
		}
	}
}
